@@ -111,20 +111,32 @@ class EsRequest:
         return res
 
     def format_scroll_url(self, host=None, port=None, route_key=None, scroll=None):
-        return "http://{}:{}/{}/_search?scroll={}".format(host if host else self.host,
-                                                          port if port else self.port, route_key, scroll)
+        return self.replace_url_kwargs("http://{host}{port}/{route_key}/_search?scroll={scroll}",
+                                       {"host": host, "port": port, "route_key": route_key, "scroll": scroll})
 
     def format_scroll_id_url(self, host=None, port=None, ):
-        return "http://{}:{}/_search/scroll".format(host if host else self.host,
-                                                    port if port else self.port)
+        return self.replace_url_kwargs("http://{host}{port}/_search/scroll",
+                                       {"host": host, "port": port})
 
     def format_es_post_url(self, host=None, port=None, route_key=None):
-        return "http://{}:{}/{}/_search".format(host if host else self.host,
-                                                port if port else self.port, route_key)
+        return self.replace_url_kwargs("http://{host}{port}/{route_key}/_search",
+                                       {"host": host, "port": port, "route_key": route_key})
 
     def format_url(self, path, host=None, port=None):
-        return "http://{}:{}{}".format(host if host else self.host,
-                                       port if port else self.port, path)
+        return self.replace_url_kwargs("http://{host}{port}{path}",
+                                       {"host": host, "port": port, "path": path})
+
+    def replace_url_kwargs(self, replace_url, replace_kwargs):
+        if not replace_kwargs["host"]:
+            replace_kwargs["host"] = self.host
+        if not replace_kwargs["port"]:
+            replace_kwargs["port"] = self.port
+        if replace_kwargs.get("port"):
+            replace_kwargs["port"] = f':{replace_kwargs["port"]}'
+        else:
+            replace_kwargs["port"] = ""
+        replace_url = replace_url.format(**replace_kwargs)
+        return replace_url
 
     def close(self):
         pass
